diff mbox series

wifi: mac80211: Abort running CCA when stopping AP

Message ID 20230504061049.21082-1-michael-cy.lee@mediatek.com
State New
Headers show
Series wifi: mac80211: Abort running CCA when stopping AP | expand

Commit Message

Michael-CY Lee May 4, 2023, 6:10 a.m. UTC
From: Michael Lee <michael-cy.lee@mediatek.com>

Signed-off-by: Michael Lee <michael-cy.lee@mediatek.com>
---
 net/mac80211/cfg.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
diff mbox series

Patch

diff --git a/net/mac80211/cfg.c b/net/mac80211/cfg.c
index 343ce2b..e6df30d 100644
--- a/net/mac80211/cfg.c
+++ b/net/mac80211/cfg.c
@@ -1537,9 +1537,10 @@  static int ieee80211_stop_ap(struct wiphy *wiphy, struct net_device *dev,
 		sdata_dereference(link->u.ap.unsol_bcast_probe_resp,
 				  sdata);
 
 	/* abort any running channel switch */
 	mutex_lock(&local->mtx);
 	link_conf->csa_active = false;
+	link_conf->color_change_active = false;
 	if (link->csa_block_tx) {
 		ieee80211_wake_vif_queues(local, sdata,
 					  IEEE80211_QUEUE_STOP_REASON_CSA);
@@ -1537,9 +1537,10 @@  static int ieee80211_stop_ap(struct wiphy *wiphy, struct net_device *dev,
 				  sdata);
 
-	/* abort any running channel switch */
+	/* abort any running channel switch or color change */
 	mutex_lock(&local->mtx);
 	link_conf->csa_active = false;